==> nextcloud-24.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/ro.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Panou",
    "Dashboard app" : "Panou de bord aplicație",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "Începeți ziua în cunoștință de cauză\n\nTabloul de bord Nextcloud este punctul dumneavoastră de pornire al zilei, oferindu-vă un\nprivire de ansamblu asupra viitoarelor dvs. întâlniri, e-mailurilor urgente, mesajelor de chat,\nbilete primite, cele mai recente tweet-uri și multe altele! Utilizatorii pot adăuga widget-urile\ncare le plac și să schimbe fundalul după bunul lor plac.",
    "Customize" : "Personalizează",
    "Edit widgets" : "Editează widget",
    "Get more widgets from the App Store" : "Obține mai multe widget-uri din App Store",
    "Change background image" : "Schimbă imaginea de fundal",
    "Weather service" : "Serviciu de vreme",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Pentru securitatea ta, datele despre vreme sunt cerute de către serverul Nextcloud din partea ta pentru ca serviciul de vreme să nu primească date confidențiale.",
    "Weather data from Met.no" : "Date despre vreme de la Met.no",
    "geocoding with Nominatim" : "geocoding cu Nominatim",
    "elevation data from OpenTopoData" : "date despre elevație de la OpenTopoData",
    "Weather" : "Vreme",
    "Status" : "Stare",
    "Good morning" : "Bună dimineața",
    "Good morning, {name}" : "Bună dimineața, {name}",
    "Good afternoon" : "Bună ziua",
    "Good afternoon, {name}" : "Bună ziua, {name}",
    "Good evening" : "Bună seara",
    "Good evening, {name}" : "Bună seara, {name}",
    "Hello" : "Bună",
    "Hello, {name}" : "Bună, {name}",
    "Pick from Files" : "Alege din Fișiere",
    "Default images" : "Imagini implicite",
    "Plain background" : "Fundal simplu",
    "Insert from {productName}" : "Introduce din {productName}",
    "Show something" : "Arată ceva"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> nextcloud-25.0.2-4-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/ro.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Panou",
    "Dashboard app" : "Panou de bord aplicație",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "Începeți ziua în cunoștință de cauză\n\nTabloul de bord Nextcloud este punctul dumneavoastră de pornire al zilei, oferindu-vă un\nprivire de ansamblu asupra viitoarelor dvs. întâlniri, e-mailurilor urgente, mesajelor de chat,\nbilete primite, cele mai recente tweet-uri și multe altele! Utilizatorii pot adăuga widget-urile\ncare le plac și să schimbe fundalul după bunul lor plac.",
    "Customize" : "Personalizează",
    "Edit widgets" : "Editează widget",
    "Get more widgets from the App Store" : "Obține mai multe widget-uri din App Store",
    "Weather service" : "Serviciu de vreme",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Pentru securitatea ta, datele despre vreme sunt cerute de către serverul Nextcloud din partea ta pentru ca serviciul de vreme să nu primească date confidențiale.",
    "Weather data from Met.no" : "Date despre vreme de la Met.no",
    "geocoding with Nominatim" : "geocoding cu Nominatim",
    "elevation data from OpenTopoData" : "date despre elevație de la OpenTopoData",
    "Weather" : "Vreme",
    "Status" : "Stare",
    "Good morning" : "Bună dimineața",
    "Good morning, {name}" : "Bună dimineața, {name}",
    "Good afternoon" : "Bună ziua",
    "Good afternoon, {name}" : "Bună ziua, {name}",
    "Good evening" : "Bună seara",
    "Good evening, {name}" : "Bună seara, {name}",
    "Hello" : "Bună",
    "Hello, {name}" : "Bună, {name}",
    "Show something" : "Arată ceva",
    "Change background image" : "Schimbă imaginea de fundal",
    "Pick from Files" : "Alege din Fișiere",
    "Default images" : "Imagini implicite",
    "Plain background" : "Fundal simplu",
    "Insert from {productName}" : "Introduce din {productName}"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
